==> xreview_0.95.1.zip: xreview/review.php <==
<?php
require('../../mainfile.php');
include_once XOOPS_ROOT_PATH.'/class/xoopsblock.php';

global $xoopsUser;
global $xoopsModule;

//----------
// 
//----------
$xoopsDB =& XoopsDatabaseFactory::getDatabaseConnection();
$myts =& MyTextSanitizer::getInstance();

//------------------------------------------------------
// ¥å
// ɽ¤ϥ⥸塼θ¤뤫ɤǣϣ
//------------------------------------------------------
$edit_auth = 0;

if($xoopsUser != NULL) {
	$sql = "select group_id,access_type  from ".$xoopsDB->prefix( 'xreview_auth' );
	$res = $xoopsDB->query($sql);
	while($row = $xoopsDB->fetchArray($res))
	{
		foreach($xoopsUser->_groups	 as $user_group_id)
		{
			if ($user_group_id == $row['group_id'])
			{
				if ($row['access_type'] == "regist")
				{
					$edit_auth = 1;
				} else {
					//
				}
			}
		}
	}
}

//--------------------------
// ȤʤURI
//--------------------------
$url        = substr(XOOPS_URL, strpos(XOOPS_URL, "//")+2);
$root_dir   = substr($url, strpos($url, "/"));
$target_uri = substr($myts->addSlashes($_SERVER['REQUEST_URI']), strlen(root_dir) + 1);

//--------------------------
// ### USERID ###
//--------------------------
if($edit_auth == 1) {
	$userid = $xoopsUser->getVar("uid");
} else {
	$userid = "";
}
//-------------------------------
// ### Preparation for SMARTY ###
//-------------------------------
$smarty = $GLOBALS["xoopsTpl"];
$tmp_path = XOOPS_ROOT_PATH."/modules/xreview/templates/blocks/xreview_block.html"; // revise by chika3

//--------------------------------------------
// ɾ
// ڥ졼==ɾԤξӳ
//--------------------------------------------
$sql  = "select * from ".$xoopsDB->prefix( 'xreview_data' );
if( $edit_auth==1 ) {
	$sql .= " where user_id <> ".intval($userid)." AND request_uri = ".$xoopsDB->quoteString($target_uri);
} else {
	$sql .= " where request_uri = ".$xoopsDB->quoteString($target_uri);
}
$res = $xoopsDB->query($sql);
$item = array();
while($row = $xoopsDB->fetchArray($res))
{
	//------------------
	// ɾ
	//------------------
	//assign
	$reviewer_user_id = $row['user_id'];
	$point = intval($row['point']);
	$item['user_id'] = $myts->htmlSpecialChars( $reviewer_user_id );
	$item['id'] = $myts->htmlSpecialChars( $row['id'] );
	$item['comment'] = $myts->htmlSpecialChars( $row['comment'] );
	$item['point']   = $myts->htmlSpecialChars( $point );

	//------------------
	// ɾԤξ
	//------------------
	$user_sql  = "select * from ".$xoopsDB->prefix( 'users' );
	$user_sql .= " where uid = " . intval($reviewer_user_id);
	$user_res = $xoopsDB->query($user_sql);
	while($user_row = $xoopsDB->fetchArray($user_res))
	{
		//assign
		$item['user_name'] = $myts->htmlSpecialChars( $user_row['uname'] );
		$item['user_image'] = $myts->htmlSpecialChars( $user_row['user_avatar'] );
	}

	if( ($reviewer_user_id == $userid) && ($edit_auth==1) ) {
	} else {
		$smarty->append("mb", $item);
	}
}

//------------------------------
//ڥ졼ξ(Խ)
//------------------------------

if( ($edit_auth==1) ) {
	// ɾ
	$sql  = "select * from ".$xoopsDB->prefix( 'xreview_data' );
	$sql .= " where user_id = ".intval($userid)." AND request_uri = ".$xoopsDB->quoteString($target_uri);
	$res = $xoopsDB->query($sql);
	if ($row = $xoopsDB->fetchArray($res)){
		$myPoint = intval($row['point']);
		$smarty->assign("myComment", $myts->htmlSpecialChars( $row['comment'] ));
		$smarty->assign("myPoint", $myts->htmlSpecialChars( $myPoint ) );
		$smarty->assign("myPoint".$myPoint, "selected" );
		$smarty->assign("display_sw",1);
		//ͽ
		$smarty->assign("myTitle", $myts->htmlSpecialChars( $xoopsModule->getVar('name') ) );
	} else {
		$smarty->assign("myComment", "" );
		$smarty->assign("myPoint", $myts->htmlSpecialChars( "brank" ) );
		$smarty->assign("myTitle", $myts->htmlSpecialChars( $xoopsModule->getVar('name') ) );
	}

	// ɾԤξ
	$user_sql  = "select * from ".$xoopsDB->prefix( 'users' );
	$user_sql .= " where uid = " . intval($userid);
	$user_res = $xoopsDB->query($user_sql);
	while($user_row = $xoopsDB->fetchArray($user_res)){
		//assign
		$smarty->assign("myName", $myts->htmlSpecialChars( $user_row['uname'] ));
		$smarty->assign("myImage", $myts->htmlSpecialChars( $user_row['user_avatar'] ));
	}
}

//----------
// Խ
//----------
$smarty->assign("edit_sw",$edit_auth);

//----------------
// ### Display ###
//----------------
$smarty->display($tmp_path);

?>

==> xreview_0.95.2.zip: xreview/review.php <==
<?php
require('../../mainfile.php');
include_once XOOPS_ROOT_PATH.'/class/xoopsblock.php';

global $xoopsUser;
global $xoopsModule;

//----------
// 
//----------
$xoopsDB =& XoopsDatabaseFactory::getDatabaseConnection();
$myts =& MyTextSanitizer::getInstance();

//------------------------------------------------------
// ¥å
// ɽ¤ϥ⥸塼θ¤뤫ɤǣϣ
//------------------------------------------------------
$edit_auth = 0;

if($xoopsUser != NULL) {
	$sql = "select group_id,access_type  from ".$xoopsDB->prefix( 'xreview_auth' );
	$res = $xoopsDB->query($sql);
	while($row = $xoopsDB->fetchArray($res))
	{
		foreach($xoopsUser->_groups	 as $user_group_id)
		{
			if ($user_group_id == $row['group_id'])
			{
				if ($row['access_type'] == "regist")
				{
					$edit_auth = 1;
				} else {
					//
				}
			}
		}
	}
}

//--------------------------
// ȤʤURI
//--------------------------
$url        = substr(XOOPS_URL, strpos(XOOPS_URL, "//")+2);
//Զ罤
$slashpos = strpos($url, "/");
	$root_dir = "";
if($slashpos == false) {
} else {
	$root_dir = substr($url, $slashpos);
}
//Զ罤
$target_uri = substr($myts->addSlashes($_SERVER['REQUEST_URI']), strlen($root_dir));

//--------------------------
// ### USERID ###
//--------------------------
if($edit_auth == 1) {
	$userid = $xoopsUser->getVar("uid");
} else {
	$userid = "";
}
//-------------------------------
// ### Preparation for SMARTY ###
//-------------------------------
$smarty = $GLOBALS["xoopsTpl"];
$tmp_path = XOOPS_ROOT_PATH."/modules/xreview/templates/blocks/xreview_block.html"; // revise by chika3

//--------------------------------------------
// ɾ
// ڥ졼==ɾԤξӳ
//--------------------------------------------
$sql  = "select * from ".$xoopsDB->prefix( 'xreview_data' );
if( $edit_auth==1 ) {
	$sql .= " where user_id <> ".intval($userid)." AND request_uri = ".$xoopsDB->quoteString($target_uri);
} else {
	$sql .= " where request_uri = ".$xoopsDB->quoteString($target_uri);
}

$res = $xoopsDB->query($sql);
$item = array();
while($row = $xoopsDB->fetchArray($res))
{
	//------------------
	// ɾ
	//------------------
	//assign
	$reviewer_user_id = $row['user_id'];
	$point = intval($row['point']);
	$item['user_id'] = $myts->htmlSpecialChars( $reviewer_user_id );
	$item['id'] = $myts->htmlSpecialChars( $row['id'] );
	$item['comment'] = $myts->htmlSpecialChars( $row['comment'] );
	$item['point']   = $myts->htmlSpecialChars( $point );

	//------------------
	// ɾԤξ
	//------------------
	$user_sql  = "select * from ".$xoopsDB->prefix( 'users' );
	$user_sql .= " where uid = " . intval($reviewer_user_id);
	$user_res = $xoopsDB->query($user_sql);
	while($user_row = $xoopsDB->fetchArray($user_res))
	{
		//assign
		$item['user_name'] = $myts->htmlSpecialChars( $user_row['uname'] );
		$item['user_image'] = $myts->htmlSpecialChars( $user_row['user_avatar'] );
	}

	if( ($reviewer_user_id == $userid) && ($edit_auth==1) ) {
	} else {
		$smarty->append("mb", $item);
	}
}

//------------------------------
//ڥ졼ξ(Խ)
//------------------------------

if( ($edit_auth==1) ) {
	// ɾ
	$sql  = "select * from ".$xoopsDB->prefix( 'xreview_data' );
	$sql .= " where user_id = ".intval($userid)." AND request_uri = ".$xoopsDB->quoteString($target_uri);
	$res = $xoopsDB->query($sql);
	if ($row = $xoopsDB->fetchArray($res)){
		$myPoint = intval($row['point']);
		$smarty->assign("myComment", $myts->htmlSpecialChars( $row['comment'] ));
		$smarty->assign("myPoint", $myts->htmlSpecialChars( $myPoint ) );
		$smarty->assign("myPoint".$myPoint, "selected" );
		$smarty->assign("display_sw",1);
		//ͽ
		$smarty->assign("myTitle", $myts->htmlSpecialChars( $xoopsModule->getVar('name') ) );
	} else {
		$smarty->assign("myComment", "" );
		$smarty->assign("myPoint", $myts->htmlSpecialChars( "brank" ) );
		$smarty->assign("myTitle", $myts->htmlSpecialChars( $xoopsModule->getVar('name') ) );
	}

	// ɾԤξ
	$user_sql  = "select * from ".$xoopsDB->prefix( 'users' );
	$user_sql .= " where uid = " . intval($userid);
	$user_res = $xoopsDB->query($user_sql);
	while($user_row = $xoopsDB->fetchArray($user_res)){
		//assign
		$smarty->assign("myName", $myts->htmlSpecialChars( $user_row['uname'] ));
		$smarty->assign("myImage", $myts->htmlSpecialChars( $user_row['user_avatar'] ));
	}
}

//----------
// Խ
//----------
$smarty->assign("edit_sw",$edit_auth);

//----------------
// ### Display ###
//----------------
$smarty->display($tmp_path);

?>
